# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`x2go`](#x2go): Install and configure the x2go client and server components  x2go does not work well with compositing window managers.  It is suggested that 
* [`x2go::install`](#x2go--install): == Class x2go::install  This class is called from x2go for install.
* [`x2go::server`](#x2go--server): Install and configure the x2go server
* [`x2go::server::clean_sessions`](#x2go--server--clean_sessions): Manage the x2gocleansessions service

## Classes

### <a name="x2go"></a>`x2go`

Install and configure the x2go client and server components

x2go does not work well with compositing window managers.

It is suggested that you use the `simp-gnome` module and enable MATE support
for use with x2go.

#### Parameters

The following parameters are available in the `x2go` class:

* [`client`](#-x2go--client)
* [`server`](#-x2go--server)
* [`package_ensure`](#-x2go--package_ensure)

##### <a name="-x2go--client"></a>`client`

Data type: `Boolean`

Whether or not the system is a x2go client

Default value: `true`

##### <a name="-x2go--server"></a>`server`

Data type: `Boolean`

Whether or not the system is a x2go server

Default value: `false`

##### <a name="-x2go--package_ensure"></a>`package_ensure`

Data type: `Simplib::PackageEnsure`

The state that packages managed by this module should be in

Default value: `simplib::lookup('simp_options::package_ensure', { 'default_value' => 'installed' })`

### <a name="x2go--install"></a>`x2go::install`

== Class x2go::install

This class is called from x2go for install.

### <a name="x2go--server"></a>`x2go::server`

Install and configure the x2go server

#### Parameters

The following parameters are available in the `x2go::server` class:

* [`config`](#-x2go--server--config)
* [`agent_options`](#-x2go--server--agent_options)
* [`config_file`](#-x2go--server--config_file)
* [`agent_config_file`](#-x2go--server--agent_config_file)
* [`session_service`](#-x2go--server--session_service)

##### <a name="-x2go--server--config"></a>`config`

Data type: `Hash[String[1], Hash[String[1], NotUndef]]`

A Hash of INI settings targeted at the x2goserver.conf file

Options not defined here will simply be added to the configuration file
without validation.

**UNMANAGED ENTRIES IN THE CONFIG FILE WILL BE PURGED**

Options take the following form:

```
Hash[
  Hash[
    String[1], # This is the INI header
    Hash[
      String[1], # This is an item key
      String[1], # This is an item value
    ]
  ]
]
```
@see x2goserver.conf(5)
@see data/common.yml

Options:

* **limit** `Hash`: users
A Hash of users specifying the maximum number of simultaneous sessions
allowed in an X2Go server farm

* To avoid resource explosion, it is highly recommended that you restrict
  by group if possible

@example Specify user limits in Hiera
  x2go::server::config:
    limit users:
      'user1': 2
      'user2': 4
* **limit** `Hash`: groups
A Hash of groups specifying the maximum number of simultaneous sessions
allowed in an X2Go server farm

@example Specify group limits in Hiera
  x2go::server::config:
    limit_groups:
      'group1': 20
* **security** `Hash`: A key/value set of strings that manage security settings

@example Specify the SSHFS umask in Hiera
  x2go::server::config:
    security:
      umask: '"0117"'
* **log** `Hash`: A key/value set of strings that manage log settings

@example Specify the log level in Hiera
  x2go::server::config:
    log:
      loglevel: 'debug'

##### <a name="-x2go--server--agent_options"></a>`agent_options`

Data type: `Hash[String[1], Optional[Scalar]]`

The options to add to the x2goagent.options file

* Options are provided in a key/value pair hash
* You **MUST** provide the flag for the option if one is present
* No validation is done on provided options
* Options that do not take an argument should have their value set to Undef
  or `~` in Hiera

@example Setting options in Hiera
  x2go::agent_options:
    "+bs": ~
    "-lf": 1024
    "nologo": ~

@see nxagent -h
@see data/common.yaml

##### <a name="-x2go--server--config_file"></a>`config_file`

Data type: `Stdlib::AbsolutePath`

The location of the main server configuration file

Default value: `'/etc/x2go/x2goserver.conf'`

##### <a name="-x2go--server--agent_config_file"></a>`agent_config_file`

Data type: `Stdlib::AbsolutePath`

The location of the agent configuration file

Default value: `'/etc/x2go/x2goagent.options'`

##### <a name="-x2go--server--session_service"></a>`session_service`

Data type: `Boolean`

Enable the x2gocleansessions service to enable full accounting and resuming
of sessions

Default value: `true`

### <a name="x2go--server--clean_sessions"></a>`x2go::server::clean_sessions`

Manage the x2gocleansessions service

